package ACME::PM::Voronezh;

use warnings;
use strict;

=head1 NAME

ACME::PM::Voronezh - Talks by Voronezh.pm

=head1 VERSION

Version 0.02

=cut

our $VERSION = '0.02';


=head1 SYNOPSIS

Welcome to Voronezh.PM!


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc ACME::PM::Voronezh


You can also look for information at:

=over 4

=item * Voronezh.PM

L<http://voronezh.pm.org/>

=item * Mailing list

L<http://groups.google.com/group/voronezh-pm>

=item * Twitter

L<http://twitter.com/voronezh_pm>

=item * Search CPAN

L<http://search.cpan.org/dist/ACME-PM-Voronezh/>

=back


=head1 AUTHOR

Alexander Nusov, C<< <alexander.nusov+cpan at gmail.com> >>


=head1 ACKNOWLEDGEMENTS

I am grateful to Dmitry Degtyarev C<< <degtyarev.dm at gmail.com> >> who inspired the idea of creating the group.


=head1 LICENSE AND COPYRIGHT

Copyright 2010 Alexander Nusov.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of ACME::PM::Voronezh
